@@ -69,6 +69,7 @@ FIELDS = [
   ["*bonding","na",0,"Bonding Mode",True,"",["na","master","slave"],"str"],
   ["*bonding_master","",0,"Bonding Master",True,"",0,"str"],
   ["*bonding_opts","",0,"Bonding Opts",True,"",0,"str"],
+  ["*management",False,0,"Management Interface",True,"Is this the management interface?",0,"bool"],
   ["*static",False,0,"Static",True,"Is this interface static?",0,"bool"],
   ["*subnet","",0,"Subnet",True,"",0,"str"],
   ["*dhcp_tag","",0,"DHCP Tag",True,"",0,"str"],
@@ -80,11 +81,10 @@ FIELDS = [
   ["*ipv6_mtu","",0,"IPv6 MTU",True,"",0,"str"],
   ["*ipv6_static_routes",[],0,"IPv6 Static Routes",True,"",0,"list"],
   ["*ipv6_default_gateway","",0,"IPv6 Default Gateway",True,"",0,"str"],
-  ["network_widget_c","",0,"Add Management Class",True,"",0,"str"], # not a real field, a marker for the web app
   ["mgmt_classes",[],0,"Management Classes",True,"For external config management",0,"list"],
-  ["network_widget_d","",0,"Remove Selected Classes",True,"",0,"str"], # not a real field, a marker for the web app
   ["mgmt_parameters","<<inherit>>",0,"Management Parameters",True,"Parameters which will be handed to your management application (Must be valid YAML dictionary)", 0,"str"],
-  ["fetchable_files",{},0,"Fetchable Files",True,"Templates for tftp or wget",0,"dict"],
+  [ "boot_files",{},'<<inherit>>',"TFTP Boot Files",True,"Files copied into tftpboot beyond the kernel/initrd",0,"list"],
+  ["fetchable_files",{},'<<inherit>>',"Fetchable Files",True,"Templates for tftp or wget",0,"dict"],
   ["template_files",{},0,"Template Files",True,"File mappings for built-in configuration management",0,"dict"],
   ["redhat_management_key","<<inherit>>",0,"Red Hat Management Key",True,"Registration key for RHN, Satellite, or Spacewalk",0,"str"],
   ["redhat_management_server","<<inherit>>",0,"Red Hat Management Server",True,"Address of Satellite or Spacewalk Server",0,"str"],
@@ -139,6 +139,7 @@ class System(item.Item):
                 "bonding"        : "",
                 "bonding_master" : "",
                 "bonding_opts"   : "",
+                "management"     : False,
                 "dns_name"       : "",
                 "static_routes"  : [],
                 "ipv6_address"   : "",
@@ -292,6 +293,11 @@ class System(item.Item):
         intf["static"] = utils.input_boolean(truthiness)
         return True
 
+    def set_management(self,truthiness,interface):
+        intf = self.__get_interface(interface)
+        intf["management"] = utils.input_boolean(truthiness)
+        return True
+
     def set_ip_address(self,address,interface):
         """
         Assign a IP or hostname in DHCP when this MAC boots.
@@ -609,6 +615,7 @@ class System(item.Item):
             if field == "bonding"             : self.set_bonding(value, interface)
             if field == "bondingmaster"       : self.set_bonding_master(value, interface)
             if field == "bondingopts"         : self.set_bonding_opts(value, interface)
+            if field == "management"          : self.set_management(value, interface)
             if field == "staticroutes"        : self.set_static_routes(value, interface)
             if field == "ipv6address"         : self.set_ipv6_address(value, interface)
             if field == "ipv6secondaries"     : self.set_ipv6_secondaries(value, interface)
