@@ -152,6 +152,7 @@ class ImportVMWareManager:
         # and then make sure nothing is already there.
 
         self.path = os.path.normpath( "%s/ks_mirror/%s" % (self.settings.webdir, self.mirror_name) )
+        self.rootdir = os.path.normpath( "%s/ks_mirror/%s" % (self.settings.webdir, self.mirror_name) )
         if os.path.exists(self.path) and self.arch is None:
             # FIXME : Raise exception even when network_root is given ?
             utils.die(self.logger,"Something already exists at this import location (%s).  You must specify --arch to avoid potentially overwriting existing files." % self.path)
@@ -709,12 +710,12 @@ class ImportVMWareManager:
                         distro.set_tree_build_time(ds)
                     profile.set_kickstart(ks)
                     if flavor == "esxi":
-                        self.logger.info("This is an ESXi distro - adding extra PXE files to fetchable-files list")
-                        # add extra files to fetchable_files in the distro
-                        fetchable_files = ''
+                        self.logger.info("This is an ESXi distro - adding extra PXE files to boot-files list")
+                        # add extra files to boot_files in the distro
+                        boot_files = ''
                         for file in ('vmkernel.gz','sys.vgz','cim.vgz','ienviron.vgz','install.vgz'):
-                           fetchable_files += '$img_path/%s=%s/%s ' % (file,self.path,file)
-                        distro.set_fetchable_files(fetchable_files.strip())
+                           boot_files += '$img_path/%s=%s/%s ' % (file,self.path,file)
+                        distro.set_boot_files(boot_files.strip())
                     self.profiles.add(profile,save=True)
 
             self.configure_tree_location(distro)
@@ -753,7 +754,7 @@ class ImportVMWareManager:
             self.set_install_tree( distro, tree)
 
     def get_rootdir(self):
-        return self.mirror
+        return self.rootdir
 
     def get_pkgdir(self):
         if not self.pkgdir:
