@@ -2,7 +2,7 @@
 Serializer code for cobbler
 Now adapted to support different storage backends
 
-Copyright 2006-2008, Red Hat, Inc
+Copyright 2006-2009, Red Hat, Inc
 Michael DeHaan <mdehaan@redhat.com>
 
 This program is free software; you can redistribute it and/or modify
@@ -28,26 +28,18 @@ import fcntl
 import traceback
 import sys
 import signal
+import time
 
 from cexceptions import *
 import api as cobbler_api
 
 LOCK_ENABLED = True
 LOCK_HANDLE = None
-BLOCK_SIGNAL = True
 
 def handler(num,frame): 
-   print sys.stderr, "Ctrl-C not allowed during writes.  Please wait."
+   print >> sys.stderr, "Ctrl-C not allowed during writes.  Please wait."
    return True
     
-def no_ctrl_c():
-   signal.signal(signal.SIGINT, handler)
-   return True
-
-def ctrl_c_ok():
-   signal.signal(signal.SIGINT, signal.default_int_handler)
-   return True   
-
 def __grab_lock():
     """
     Dual purpose locking:
@@ -61,21 +53,26 @@ def __grab_lock():
                 fd.close()
             LOCK_HANDLE = open("/var/lib/cobbler/lock","r")
             fcntl.flock(LOCK_HANDLE.fileno(), fcntl.LOCK_EX)
-        if BLOCK_SIGNAL:
-            no_ctrl_c()
         return True
     except:
         # this is pretty much FATAL, avoid corruption and quit now.
         traceback.print_exc()
         sys.exit(7)
 
-def __release_lock():
+def __release_lock(with_changes=False):
+    if with_changes:
+        # this file is used to know when the last config change
+        # was made -- allowing the API to work more smoothly without
+        # a lot of unneccessary reloads.  
+        old = os.umask(0x777)
+        fd = open("/var/lib/cobbler/.mtime","w")
+        fd.write("%f" % time.time())
+        fd.close()
+        os.umask(old)
     if LOCK_ENABLED:
         LOCK_HANDLE = open("/var/lib/cobbler/lock","r")
         fcntl.flock(LOCK_HANDLE.fileno(), fcntl.LOCK_UN)
         LOCK_HANDLE.close()
-    if BLOCK_SIGNAL:
-        ctrl_c_ok()
     return True
 
 def serialize(obj):
@@ -99,7 +96,7 @@ def serialize_item(collection, item):
         rc = storage_module.serialize(collection)
     else:
         rc = save_fn(collection,item)
-    __release_lock()
+    __release_lock(with_changes=True)
     return rc
 
 def serialize_delete(collection, item):
@@ -113,7 +110,7 @@ def serialize_delete(collection, item):
         rc = storage_module.serialize(collection)
     else:
         rc = delete_fn(collection,item)
-    __release_lock()
+    __release_lock(with_changes=True)
     return rc
 
 def deserialize(obj,topological=True):
@@ -160,7 +157,10 @@ def __get_storage_module(collection_type):
     Look up serializer in /etc/cobbler/modules.conf
     """    
     capi = cobbler_api.BootAPI()
-    return capi.get_module_from_file("serializers",collection_type,"serializer_yaml")
+    if not capi.use_couch:
+        return capi.get_module_by_name("serializer_catalog")
+    else:
+        return capi.get_module_by_name("serializer_couch")
 
 if __name__ == "__main__":
     __grab_lock()
