@@ -23,6 +23,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 import utils
 from utils import _
 
+import os.path
+
 TESTMODE = False
 
 # defaults is to be used if the config file doesn't contain the value
@@ -82,6 +84,7 @@ DEFAULTS = {
     "next_server"                 : "127.0.0.1",
     "power_management_default_type" : "ipmitool",
     "power_template_dir"          : "/etc/cobbler/power",
+    "puppet_auto_setup"           : 0,
     "pxe_just_once"               : 0,
     "pxe_template_dir"            : "/etc/cobbler/pxe",
     "redhat_management_permissive" : 0,
@@ -107,9 +110,12 @@ DEFAULTS = {
     "yum_distro_priority"         : 1,
     "yumdownloader_flags"         : "--resolve",
     "reposync_flags"              : "-l -m -d",
-    "ldap_management_default_type": "authconfig"
+    "ldap_management_default_type": "authconfig",
+    "consoles"                     : "/var/consoles"
 }
 
+if os.path.exists("/srv/www/"):
+    DEFAULTS["webdir"] = "/srv/www/cobbler"
 
 class Settings:
 
