@@ -3,7 +3,7 @@ Cobbler uses Cheetah templates for lots of stuff, but there's
 some additional magic around that to deal with snippets/etc.
 (And it's not spelled wrong!)
 
-Copyright 2008, Red Hat, Inc
+Copyright 2008-2009, Red Hat, Inc
 Michael DeHaan <mdehaan@redhat.com>
 
 This program is free software; you can redistribute it and/or modify
@@ -29,16 +29,33 @@ from cexceptions import *
 from template_api import Template
 from utils import *
 import utils
+import clogger
+
+import Cheetah
+major, minor, release = Cheetah.Version.split('.')[0:3]
+fix_cheetah_class = int(major) >= 2 and int(minor) >=4 and int(release) >= 2
+
+try:
+    import functools
+except:
+    functools = None
 
 class Templar:
 
-    def __init__(self,config):
+    def __init__(self,config=None,logger=None):
         """
         Constructor
         """
-        self.config      = config
-        self.api         = config.api
-        self.settings    = config.settings()
+
+        if logger is None:
+            logger = clogger.Logger()
+        self.logger = logger
+
+        if config is not None:
+            self.config      = config
+            self.api         = config.api
+            self.settings    = config.settings()
+        self.last_errors = []
 
     def check_for_invalid_imports(self,data):
         """
@@ -50,11 +67,9 @@ class Templar:
         for line in lines:
             if line.find("#import") != -1:
                rest=line.replace("#import","").replace(" ","").strip()
-               if rest not in [ "time", "random" ]:
-                   print "warning"
+               if rest not in self.settings.cheetah_import_whitelist:
                    raise CX("potentially insecure import in template: %s" % rest)
 
-
     def render(self, data_input, search_table, out_path, subject=None):
         """
         Render data_input back into a file.
@@ -65,7 +80,7 @@ class Templar:
         subject is a profile or system object, if available (for snippet eval)
         """
 
-        if type(data_input) != str:
+        if not isinstance(data_input, basestring):
            raw_data = data_input.read()
         else:
            raw_data = data_input
@@ -87,7 +102,7 @@ class Templar:
                    try:
                        (server, dir) = rest.split(":",2)
                    except:
-                       raise CX(_("Invalid syntax for NFS path given during import: %s" % search_table["tree"]))
+                       raise CX("Invalid syntax for NFS path given during import: %s" % search_table["tree"])
                    line = "nfs --server %s --dir %s" % (server,dir)
                    # but put the URL part back in so koan can still see
                    # what the original value was
@@ -96,26 +111,56 @@ class Templar:
             raw_data = newdata 
 
         # tell Cheetah not to blow up if it can't find a symbol for something
-        raw_data = "#errorCatcher Echo\n" + raw_data
+        raw_data = "#errorCatcher ListErrors\n" + raw_data
+
+        table_copy = search_table.copy()
+ 
+        # for various reasons we may want to call a module inside a template and pass
+        # it all of the template variables.  The variable "template_universe" serves
+        # this purpose to make it easier to iterate through all of the variables without
+        # using internal Cheetah variables
+
+        search_table.update({
+           "template_universe" : table_copy
+        })
 
         # now do full templating scan, where we will also templatify the snippet insertions
-        t = Template(source=raw_data, errorCatcher="Echo", searchList=[search_table])
+        t = Template(source=raw_data, errorCatcher="Echo", searchList=[search_table], compilerSettings={'useStackFrame':False})
+
+        if fix_cheetah_class and functools is not None:
+            t.SNIPPET = functools.partial(t.SNIPPET, t)
+            t.read_snippet = functools.partial(t.read_snippet, t)
+
         try:
-            data_out = str(t)
+            data_out = t.respond()
+            self.last_errors = t.errorCatcher().listErrors()
         except Exception, e:
-            return utils.cheetah_exc(e)
+            if out_path is None:
+               return utils.cheetah_exc(e)
+            else:
+               # FIXME: log this
+               self.logger.error(utils.cheetah_exc(e))
+               raise CX("Error templating file: %s" % out_path)
 
         # now apply some magic post-filtering that is used by cobbler import and some
         # other places, but doesn't use Cheetah.  Forcing folks to double escape
         # things would be very unwelcome.
 
-        for x in search_table:
-           if type(search_table[x]) == str:
-               data_out = data_out.replace("@@%s@@" % x, search_table[x])
-        
+        hp = search_table.get("http_port","80")
+        server = search_table.get("server","server.example.org")
+        if hp not in (80, '80'):
+            repstr = "%s:%s" % (server, hp)
+        else:
+            repstr = server
+        search_table["http_server"] = repstr
+
+        for x in search_table.keys():
+           if type(x) == str:
+               data_out = data_out.replace("@@%s@@" % str(x), str(search_table[str(x)]))
+ 
         # remove leading newlines which apparently breaks AutoYAST ?
         if data_out.startswith("\n"):
-            data_out = data_out.strip() 
+            data_out = data_out.lstrip()
 
         if out_path is not None:
             utils.mkdir(os.path.dirname(out_path))
