@@ -38,8 +38,8 @@ def index(request):
 
    t = get_template('index.tmpl')
    html = t.render(Context({
-        'version': remote.version(request.session['token']),
-        'username':username,
+        'version' : remote.version(request.session['token']),
+        'username': username,
    }))
    return HttpResponse(html)
 
@@ -52,6 +52,7 @@ def task_created(request):
    if not test_user_authenticated(request): return login(request)
    t = get_template("task_created.tmpl")
    html = t.render(Context({
+       'version'  : remote.version(request.session['token']),
        'username' : username
    }))
    return HttpResponse(html)
@@ -69,7 +70,8 @@ def error_page(request,message):
    message = message.replace("<Fault 1: \"<class 'cobbler.cexceptions.CX'>:'","Remote exception: ")
    message = message.replace("'\">","")
    html = t.render(Context({
-       'message': message,
+       'version' : remote.version(request.session['token']),
+       'message' : message,
        'username': username
    }))
    return HttpResponse(html)
@@ -331,6 +333,7 @@ def genlist(request, what, page=None):
         'items'          : __format_items(pageditems["items"],columns),
         'pageinfo'       : pageditems["pageinfo"],
         'filters'        : filters,
+        'version'        : remote.version(request.session['token']),
         'username'       : username,
         'limit'          : limit,
         'batchactions'   : batchactions,
@@ -525,6 +528,7 @@ def import_prompt(request):
    if not test_user_authenticated(request): return login(request)
    t = get_template('import.tmpl')
    html = t.render(Context({
+       'version'  : remote.version(request.session['token']),
        'username' : username,
    }))
    return HttpResponse(html)
@@ -539,6 +543,7 @@ def check(request):
    results = remote.check(request.session['token'])
    t = get_template('check.tmpl')
    html = t.render(Context({
+       'version': remote.version(request.session['token']),
        'username' : username,
        'results'  : results
    }))
@@ -586,6 +591,7 @@ def ksfile_list(request, page=None):
    html = t.render(Context({
        'what':'ksfile',
        'ksfiles': ksfile_list,
+       'version': remote.version(request.session['token']),
        'username': username,
        'item_count': len(ksfile_list[0]),
    }))
@@ -617,6 +623,7 @@ def ksfile_edit(request, ksfile_name=None, editmode='edit'):
        'ksdata'      : ksdata,
        'editable'    : editable,
        'editmode'    : editmode,
+       'version'     : remote.version(request.session['token']),
        'username'    : username
    }))
    return HttpResponse(html)
@@ -647,7 +654,7 @@ def ksfile_save(request):
       return HttpResponseRedirect('/cobbler_web/ksfile/list')
    else:
       remote.read_or_write_kickstart_template(ksfile_name,False,ksdata,request.session['token'])
-      return HttpResponseRedirect('/cobbler_web/ksfile/edit/%s' % ksfile_name)
+      return HttpResponseRedirect('/cobbler_web/ksfile/edit/file:%s' % ksfile_name)
 
 # ======================================================================
 
@@ -669,6 +676,7 @@ def snippet_list(request, page=None):
    html = t.render(Context({
        'what'     : 'snippet',
        'snippets' : snippet_list,
+       'version'  : remote.version(request.session['token']),
        'username' : username
    }))
    return HttpResponse(html)
@@ -698,6 +706,7 @@ def snippet_edit(request, snippet_name=None, editmode='edit'):
        'snippetdata'  : snippetdata,
        'editable'     : editable,
        'editmode'     : editmode,
+       'version'      : remote.version(request.session['token']),
        'username'     : username
    }))
    return HttpResponse(html)
@@ -728,7 +737,7 @@ def snippet_save(request):
       return HttpResponseRedirect('/cobbler_web/snippet/list')
    else:
       remote.read_or_write_snippet(snippet_name,False,snippetdata,request.session['token'])
-      return HttpResponseRedirect('/cobbler_web/snippet/edit/%s' % snippet_name)
+      return HttpResponseRedirect('/cobbler_web/snippet/edit/file:%s' % snippet_name)
 
 # ======================================================================
 
@@ -748,6 +757,7 @@ def settings(request):
    t = get_template('settings.tmpl')
    html = t.render(Context({
         'settings' : results,
+        'version'  : remote.version(request.session['token']),
         'username' : username,
    }))
    return HttpResponse(html)
@@ -764,15 +774,16 @@ def events(request):
    events2 = []
    for id in events.keys():
       (ttime, name, state, read_by) = events[id]
-      events2.append([id,time.asctime(time.gmtime(ttime)),name,state])
+      events2.append([id,time.asctime(time.localtime(ttime)),name,state])
 
    def sorter(a,b):
-      return cmp(a[2],b[2])
+      return cmp(a[0],b[0])
    events2.sort(sorter)
 
    t = get_template('events.tmpl')
    html = t.render(Context({
        'results'  : events2,
+       'version'  : remote.version(request.session['token']),
        'username' : username
    }))
    return HttpResponse(html)
@@ -801,6 +812,7 @@ def eventlog(request, event=0):
       'eventstate' : eventstate,
       'eventid'    : event,
       'eventtime'  : eventtime,
+      'version'    : remote.version(request.session['token']),
       'username'  : username
    }
    html = t.render(Context(vars))
@@ -920,8 +932,6 @@ def generic_edit(request, what=None, obj_name=None, editmode="new"):
        else:
            interfaces = {}
 
-   mgmt_classes = __names_from_dicts(remote.get_mgmtclasses(),optional=False)
-
    fields = get_fields(what, child, obj)
 
    # populate some select boxes
@@ -940,13 +950,7 @@ def generic_edit(request, what=None, obj_name=None, editmode="new"):
         __tweak_field(fields, "files", "choices",    __names_from_dicts(remote.get_files()))
 
    if what in ("distro","profile","system"):
-      obj_mgmt_classes = []
-      if obj:
-          obj_mgmt_classes = obj.get('mgmt_classes',[])
-          if not isinstance(obj_mgmt_classes,list):
-              obj_mgmt_classes = [obj_mgmt_classes,]
-          obj_mgmt_classes.sort()
-      __tweak_field(fields, "mgmt_classes", "choices", obj_mgmt_classes)
+       __tweak_field(fields, "mgmt_classes", "choices", __names_from_dicts(remote.get_mgmtclasses(),optional=False))
 
    # save the fields in the session for comparison later
    request.session['%s_%s' % (what,obj_name)] = fields
@@ -956,7 +960,6 @@ def generic_edit(request, what=None, obj_name=None, editmode="new"):
    inames.sort()
    html = t.render(Context({
        'what'            : what, 
-       'use_extra_js'    : ['distro','profile','system'],
        'fields'          : fields, 
        'subobject'       : child,
        'editmode'        : editmode, 
@@ -964,7 +967,7 @@ def generic_edit(request, what=None, obj_name=None, editmode="new"):
        'interfaces'      : interfaces,
        'interface_names' : inames,
        'interface_length': len(inames),
-       'mgmt_classes'    : mgmt_classes,
+       'version'         : remote.version(request.session['token']),
        'username'        : username,
        'name'            : obj_name
    }))
@@ -1111,10 +1114,11 @@ def test_user_authenticated(request):
     # the user is considered successfully authenticated
     if request.session.has_key('token') and request.session['token'] != '':
         try:
-            token_user = remote.get_user_from_token(request.session['token'])
-            if request.session.has_key('username') and request.session['username'] == token_user:
-                username = request.session['username']
-                return True
+            if remote.token_check(request.session['token']):
+                token_user = remote.get_user_from_token(request.session['token'])
+                if request.session.has_key('username') and request.session['username'] == token_user:
+                    username = request.session['username']
+                    return True
         except:
             # just let it fall through to the 'return False' below
             pass
@@ -1137,7 +1141,11 @@ def do_login(request):
 
     remote = xmlrpclib.Server(url_cobbler_api, allow_none=True)
 
-    token = remote.login(username, password)
+    try:
+        token = remote.login(username, password)
+    except: 
+        token = None
+
     if token:
         request.session['username'] = username
         request.session['token'] = token
